# Changelog

0.3.0 (pshirali, KyleKing)
------------------------

1. #25: Fix: Extra data-descriptors from the implementation won't raise errors (pshirali)
1. #24: Implementations are prevented from inheriting from interfaces (pshirali)
1. #22: Method signatures of data-descriptors are additionally verified (pshirali)
1. #21: Interface errors are collected and reported together (KyleKing)


0.2.0 (pshirali, ksindi)
------------------------

1. #18: Use twine for uploading to pypi. (ksindi)
1. #16: Detect and verify async methods, generators and their combination (pshirali)
1. #15: Project cleanup: flake8, deepsource, makefile and setup.py (pshirali)
1. #11: Detect and verify staticmethods, classmethods (pshirali)
1. #10: Fix: Verification when implementation has a property decorator (pshirali)
1. #8,#9: Moved license from MIT to Apache 2.0 (ksindi, pshirali)
1. #5: Added additional tests for existing scenarios. Improved others. (pshirali)
